@@ -41,8 +41,8 @@ def installed(target, arg):
     pkg = list(target.Package.installed(arg))
     print('\n'.join(f'{n} {v}' for n, v in pkg))
 
-def available(target, arg):
-    pkg = list(target.Package.available(arg))
+def installable(target, arg):
+    pkg = target.Package.installable(arg)
     print('\n'.join(f'{n} {v}' for n, v in pkg))
 
 def bigs(target, arg):
