@@ -17,7 +17,7 @@ helps = dict(
     ''',
     installed = '''list installed packages
     ''',
-    available = '''list avaiable packages
+    installable = '''list avaiable packages
     ''',
     bigs = '''list the bigest installed packages
     ''',
